<?php
/*
 * @version		$Id: default.php 3.3.0 2019-01-10 $
 * @package		All Video Share
 * @copyright   Copyright (C) 2012-2019 MrVinoth
 * @license     GNU/GPL http://www.gnu.org/licenses/gpl-2.0.html
*/

// no direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

// Video Sources
$sources = array();

switch ( $this->video->type ) {
    case 'youtube':
    case 'vimeo':
        $sources[] = array(
            'type' => 'video/' . $this->video->type,
            'src'  => $this->video->video
        );
        break;
    case 'hls':
        $sources[] = array(
            'type' => 'application/x-mpegurl',
            'src'  => $this->video->hls
        );
        break;
    case 'general':
    case 'url': 
    case 'upload':  
        // SD
        $parse_url = parse_url( $this->video->video );
        $ext = pathinfo( $parse_url['path'], PATHINFO_EXTENSION );
        if ( 'mov' == $ext ) $ext = 'mp4';

        $sources[] = array(
            'type'    => "video/$ext",
            'src'     => $this->video->video,
            'quality' => 'SD'
        );
        
        // HD
        if ( $this->hasQualitySwitcher() ) {
            $parse_url = parse_url( $this->video->hd );
            $ext = pathinfo( $parse_url['path'], PATHINFO_EXTENSION );
            if ( 'mov' == $ext ) $ext = 'mp4';
            
            $sources[] = array(
                'type'    => "video/$ext",
                'src'     => $this->video->hd,
                'quality' => 'HD'
            );
        }
        break;
}

// Video Attributes
$attributes = array(
    'controlsList' => 'nodownload',
    'playsinline'  => ''
);

if ( ! empty( $this->video->thumb ) ) {
    $attributes['poster'] = $this->video->thumb;
}

$_attributes = array();

foreach ( $attributes as $key => $value ) {
    if ( '' === $value ) {
        $_attributes[] = $key;
    } else {
        $_attributes[] = sprintf( '%s="%s"', $key, $value );
    }
}

$attributes = implode( ' ', $_attributes );

// Player Settings
$features = array();

if ( $this->player->controlbar ) {
    $features[] = 'playpause';

    if ( $this->player->timerdock ) {
        $features[] = 'current';
    }

    $features[] = 'progress';

    if ( $this->player->durationdock ) {
        $features[] = 'duration';
    }

    if ( $this->hasQualitySwitcher() ) {
        $features[] = 'quality';
    }

    $features[] = 'volume';

    if ( $this->player->fullscreendock ) {
        $features[] = 'fullscreen';
    }
}

if ( $this->hasAds() ) {
    $features[] = 'ima';
}

$features[] = 'avs';
$features[] = 'me';

$settings = array(
	'pluginPath'   => JURI::root() . 'components/com_allvideoshare/assets/mediaelement/',
    'features'     => $features,
    'startVolume'  => (int) $this->player->volumelevel / 100,
    'licenseKey'   => $this->license->licensekey,
	'hideLOGO'     => $this->license->displaylogo ? false : true,
    'logoImage'    => $this->license->logo,
	'logoPosition' => $this->license->logoposition,
	'logoOpacity'  => (int) $this->license->logoalpha / 100,
	'logoClickURL' => empty( $this->license->licensekey ) ? 'https://allvideoshare.mrvinoth.com' : $this->license->logotarget,
	'youtube'      => array( 
        'showinfo'       => 0, 
        'rel'            => 0, 
        'iv_load_policy' => 3
    )	
);

// Ads
if ( $this->hasAds() ) {
    $settings['imaAdTagUrl'] = $this->player->vast_url;

    if ( 'vast' == $this->player->ad_engine ) {
        $excerpt = '';
        if ( ! empty( $this->video->description ) ) {
            $excerpt = AllVideoShareUtils::Truncate( $this->video->description );
            $excerpt = str_replace( '...', '', $excerpt );
        }
        
        $settings['imaAdTagVariables'] = array(
			'siteUrl'     => JURI::root(),
			'videoID'     => $this->video->id,
			'videoTitle'  => $this->video->title,
			'postExcerpt' => $excerpt,
			'ipAddress'   => $this->getIpAddress()
		);
        $settings['imaVpaidMode'] = ! empty( $this->player->vpaid_mode ) ? $this->player->vpaid_mode : 'insecure';
        $settings['imaLiveStreamAdInterval'] = ! empty( $this->player->livestream_ad_interval ) ? $this->player->livestream_ad_interval : 300;
    }    
}

// GDPR Consent
if ( $this->showGdprConsent() ) {
    $settings['showGdprConsent'] = true;
    $settings['gdprConsentMessage'] = JText::_( 'GDPR_CONSENT_MESSAGE' );
    $settings['gdprConsentButtonLabel'] = JText::_( 'GDPR_CONSENT_BUTTON_LABEL' );

    $sources = [];
} else {
    $settings['showGdprConsent'] = false;
}
?>

<!DOCTYPE html>
<html>
<head>
	<meta charset="utf-8">
	<title><?php echo $this->getTitle(); ?></title>    
    <link rel="canonical" href="<?php echo $this->getURL(); ?>" />
    <meta property="og:url" content="<?php echo $this->getURL(); ?>" />
	<link rel="stylesheet" href="<?php echo JURI::root(); ?>components/com_allvideoshare/assets/mediaelement/mediaelementplayer.css?v=<?php echo ALLVIDEOSHARE_VERSION; ?>" />
    <?php if ( $this->hasQualitySwitcher() ) : ?>
        <link rel="stylesheet" href="<?php echo JURI::root(); ?>components/com_allvideoshare/assets/mediaelement/plugins/quality/quality.min.css?v=<?php echo ALLVIDEOSHARE_VERSION; ?>" />
    <?php endif; ?>
	<style type="text/css">
        html, 
        body, 
        video, 
        iframe {
            width: 100% !important;
            height: 100% !important;
            margin:0 !important; 
            padding:0 !important; 
            overflow: hidden;
        }
            
        video, 
        iframe {
            display: block;
        }
            
        .mejs__container, 
        .mejs__layer {
            width: 100% !important;
            height: 100% !important;
        }

        .mejs__ima {
            display: block;            
            cursor: pointer;
            pointer-events: none;
        }

        .ima-initialize  .mejs__ima,
        .ima-linear-display .mejs__ima,
        .ima-non-linear-display .mejs__ima {
            pointer-events: auto;
        }

        .ima-linear-display .mejs__overlay-play,
        .ima-linear-display .mejs__me,
        .ima-linear-display .mejs__controls {
            opacity: 0 !important;
            pointer-events: none;
        }

        .ima-non-linear-display .mejs__ima {
            margin-top: -50px;
            -webkit-transition: margin-top .2s; /* Safari */
            transition: margin-top .2s;
        }

        .ima-non-linear-display.ima-offscreen .mejs__ima {
            margin-top: 0px;
            -webkit-transition: margin-top .2s; /* Safari */
            transition: margin-top .2s;
        }

        .mejs__gdpr {
            color: #FFF;
            text-align: center;
            z-index: 999;
        }
        
        .mejs__gdpr-consent-block {
            margin: 15px;
            padding: 15px;
            background: #000;
            border-radius: 3px;
            opacity: 0.9;
        }
        
        .mejs__gdpr-consent-button {
            display: inline-block;
            margin-top: 10px;
            padding: 5px 15px;
            background: #F00;
            border-radius: 3px;
            cursor: pointer;
        }
        
        .mejs__gdpr-consent-button:hover {
            opacity: 0.8;
        }
		
		.contextmenu {
            position: absolute;
            top: 0;
            left: 0;
            margin: 0;
            padding: 0;
            background: #fff;
			border-radius: 2px;
			box-shadow: 1px 1px 2px #333;
            z-index: 9999999999; /* make sure it shows on fullscreen */
        }
        
        .contextmenu-item {
            margin: 0;
            padding: 8px 12px;
            font-family: 'Helvetica', Arial, serif;
            font-size: 12px;
            color: #222;		
            white-space: nowrap;
            cursor: pointer;
        }
    </style>    
    <?php
    if ( ! empty( $this->config->custom_css ) ) {
        printf( '<style type="text/css">%s</style>', $this->config->custom_css );
    }
    ?>
</head>
<body>
    <video id="player" <?php echo $attributes; ?>>
        <?php 
        foreach ( $sources as $source ) {
            if ( ! empty( $source['quality'] ) ) {
                printf( '<source type="%s" src="%s" data-quality="%s" />', $source['type'], $source['src'], $source['quality'] );
            } else {
                printf( '<source type="%s" src="%s" />', $source['type'], $source['src'] );
            }            
        }
       ?>   
	</video>

    <div id="contextmenu" class="contextmenu" style="display: none;">
        <div class="contextmenu-item">
            <?php
            if ( empty( $this->license->licensekey ) ) {
                echo 'Powered by "All Video Share"';                
            } else {
                $config = JFactory::getConfig();
                echo $config->get( 'sitename' );
            }
            ?>
        </div>
    </div>

	<script src="<?php echo JURI::root(); ?>components/com_allvideoshare/assets/mediaelement/mediaelement-and-player.min.js?v=<?php echo ALLVIDEOSHARE_VERSION; ?>" type="text/javascript"></script>
    <?php if ( 'vimeo' == $this->video->type ) : ?>
	    <script src="<?php echo JURI::root(); ?>components/com_allvideoshare/assets/mediaelement/renderers/vimeo.min.js?v=<?php echo ALLVIDEOSHARE_VERSION; ?>" type="text/javascript"></script>
    <?php endif; ?>
    <?php if ( $this->hasQualitySwitcher() ) : ?>
        <script src="<?php echo JURI::root(); ?>components/com_allvideoshare/assets/mediaelement/plugins/quality/quality.min.js?v=<?php echo ALLVIDEOSHARE_VERSION; ?>" type="text/javascript"></script>
    <?php endif; ?>
    <?php if ( $this->hasAds() ) : ?>
        <script src="https://imasdk.googleapis.com/js/sdkloader/ima3.js?v=<?php echo ALLVIDEOSHARE_VERSION; ?>" type="text/javascript"></script>
        <script src="<?php echo JURI::root(); ?>components/com_allvideoshare/assets/js/ima.js?v=<?php echo ALLVIDEOSHARE_VERSION; ?>" type="text/javascript"></script>
    <?php endif; ?>
    <script type="text/javascript">
		(function() {
			'use strict';
  
            /**
			 * A custom mediaelementjs plugin.
			 */
            Object.assign(MediaElementPlayer.prototype, {			
                buildavs: function buildavs( player, controls, layers, media ) {                
                    var t = this;
                
                    // GDPR Consent
					if ( 1 == t.options.showGdprConsent ) {							
                        t.gdprLayer = document.createElement( 'div' );
                        t.gdprLayer.className = t.options.classPrefix + 'overlay ' + t.options.classPrefix + 'layer ' + t.options.classPrefix + 'gdpr';
                        t.gdprLayer.innerHTML = ( '<div class="' + t.options.classPrefix + 'gdpr-consent-block">' ) + ( '<div class="' + t.options.classPrefix + 'gdpr-consent-message">' + t.options.gdprConsentMessage + '</div>' ) + ( '<div class="' + t.options.classPrefix + 'gdpr-consent-button">' + t.options.gdprConsentButtonLabel + '</div>' ) + '</div>';
                        
                        t.layers.appendChild( t.gdprLayer );
                        
                        t.gdprLayer.querySelector( '.' + t.options.classPrefix + 'gdpr-consent-button' ).addEventListener( 'click',  t.onGdprConsentAgreed.bind( t ) );	
                    }

                    // Custom ContextMenu
                    var contextmenu = document.getElementById( 'contextmenu' );
                    var timeout_handler = '';
                    
                    document.addEventListener( 'contextmenu', function( e ) {                    
                        if ( 3 === e.keyCode || 3 === e.which ) {
                            e.preventDefault();
                            e.stopPropagation();
                            
                            var width = contextmenu.offsetWidth,
                                height = contextmenu.offsetHeight,
                                x = e.pageX,
                                y = e.pageY,
                                doc = document.documentElement,
                                scrollLeft = ( window.pageXOffset || doc.scrollLeft ) - ( doc.clientLeft || 0 ),
                                scrollTop = ( window.pageYOffset || doc.scrollTop ) - ( doc.clientTop || 0 ),
                                left = x + width > window.innerWidth + scrollLeft ? x - width : x,
                                top = y + height > window.innerHeight + scrollTop ? y - height : y;
                    
                            contextmenu.style.display = '';
                            contextmenu.style.left = left + 'px';
                            contextmenu.style.top = top + 'px';
                            
                            clearTimeout( timeout_handler );
                            timeout_handler = setTimeout(function() {
                                contextmenu.style.display = 'none';
                            }, 1500 );				
                        }                                                     
                    });
                    
                    if ( '' != t.options.logoClickURL ) {
                        contextmenu.addEventListener( 'click', function() {
                            top.window.location.href = t.options.logoClickURL;
                        });
                    }
                    
                    document.addEventListener( 'click', function() {
                        contextmenu.style.display = 'none';								 
                    });                    
                },

                onGdprConsentAgreed: function onGdprConsentAgreed() {					
                    var t = this;                   
					t.gdprLayer.querySelector( '.' + t.options.classPrefix + 'gdpr-consent-button' ).innerHTML = '...';        

                    // Set Cookie
                    var xmlhttp;

                    if ( window.XMLHttpRequest ) {
                        xmlhttp = new XMLHttpRequest();
                    } else {
                        xmlhttp = new ActiveXObject( 'Microsoft.XMLHTTP' );
                    };
                    
                    xmlhttp.onreadystatechange = function() {                
                        if ( 4 == xmlhttp.readyState && 200 == xmlhttp.status ) {                    
                            if ( 'success' == xmlhttp.responseText ) {
                                // Reload document
                                window.location.reload();
                            }                        
                        }                    
                    };	

                    xmlhttp.open( 'GET', '<?php echo JURI::root(); ?>index.php?option=com_allvideoshare&view=player&task=gdpr&format=raw', true );
                    xmlhttp.send();  
				}
            });
            
			/**
			 * Initialize the player.
			 */
            var autoplay = <?php echo $this->player->autostart; ?>;
            var loop = <?php echo $this->player->loop; ?>;
            var is_mobile = mejs.Features.isiPad || mejs.Features.isiPhone || mejs.Features.isAndroid;

            var settings = <?php echo json_encode( $settings ); ?>;

            settings.success = function( media ) {

                if ( ! is_mobile && autoplay ) {
                    media.play();
                }

                media.addEventListener( 'ended', function( e ) {
                    if ( loop ) {
                        media.play();
                    }
                });
                
            }

			var player = new MediaElementPlayer( 'player', settings );
		})();
    </script>
</body>
</html>